@@ -1,6 +1,6 @@
 ;;; org-entities.el --- Support for special entities in Org-mode
 
-;; Copyright (C) 2010-2015 Free Software Foundation, Inc.
+;; Copyright (C) 2010-2016 Free Software Foundation, Inc.
 
 ;; Author: Carsten Dominik <carsten at orgmode dot org>,
 ;;         Ulf Stegemann <ulf at zeitform dot de>
@@ -208,8 +208,8 @@ packages to be loaded, add these packages to `org-latex-packages-alist'."
      ("upsih" "\\Upsilon" t "&upsih;" "upsilon" "upsilon" "ϒ")
      ("upsilon" "\\upsilon" t "&upsilon;" "upsilon" "upsilon" "υ")
      ("Phi" "\\Phi" t "&Phi;" "Phi" "Phi" "Φ")
-     ("phi" "\\phi" t "&phi;" "phi" "phi" "φ")
-     ("varphi" "\\varphi" t "&varphi;" "varphi" "varphi" "ɸ")
+     ("phi" "\\phi" t "&phi;" "phi" "phi" "ɸ")
+     ("varphi" "\\varphi" t "&varphi;" "varphi" "varphi" "φ")
      ("Chi" "X" nil "&Chi;" "Chi" "Chi" "Χ")
      ("chi" "\\chi" t "&chi;" "chi" "chi" "χ")
      ("acutex" "\\acute x" t "&acute;x" "'x" "'x" "𝑥́")
@@ -326,7 +326,7 @@ packages to be loaded, add these packages to `org-latex-packages-alist'."
      ("deg" "\\textdegree{}" nil "&deg;" "degree" "°" "°")
      ("prime" "\\prime" t "&prime;" "'" "'" "′")
      ("Prime" "\\prime{}\\prime" t "&Prime;" "''" "''" "″")
-     ("infin" "\\propto" t "&infin;" "[infinity]" "[infinity]" "∞")
+     ("infin" "\\infty" t "&infin;" "[infinity]" "[infinity]" "∞")
      ("infty" "\\infty" t "&infin;" "[infinity]" "[infinity]" "∞")
      ("prop" "\\propto" t "&prop;" "[proportional to]" "[proportional to]" "∝")
      ("propto" "\\propto" t "&prop;" "[proportional to]" "[proportional to]" "∝")
@@ -361,8 +361,8 @@ packages to be loaded, add these packages to `org-latex-packages-alist'."
      ("lessgtr" "\\lessgtr" t "&lessgtr;" "[less than or greater than]" "[less than or greater than]" "≶")
      ("lesseqgtr" "\\lesseqgtr" t "&lesseqgtr;" "[less than or equal or greater than or equal]" "[less than or equal or greater than or equal]" "⋚")
      ("ll" "\\ll" t  "&Lt;" "<<" "<<" "≪")
-     ("Ll" "\lll" t "&Ll;" "<<<" "<<<" "⋘")
-     ("lll" "\lll" t "&Ll;" "<<<" "<<<" "⋘")
+     ("Ll" "\\lll" t "&Ll;" "<<<" "<<<" "⋘")
+     ("lll" "\\lll" t "&Ll;" "<<<" "<<<" "⋘")
      ("gg" "\\gg" t  "&Gt;" ">>" ">>" "≫")
      ("Gg" "\\ggg" t "&Gg;" ">>>" ">>>" "⋙")
      ("ggg" "\\ggg" t "&Gg;" ">>>" ">>>" "⋙")
