@@ -41,7 +41,7 @@
 (declare-function org-get-tags "org" ())
 (declare-function org-buffer-property-keys "org"
 		  (&optional include-specials include-defaults include-columns))
-(declare-function org-entry-properties "org" (&optional pom which specific))
+(declare-function org-entry-properties "org" (&optional pom which))
 
 ;;;; Customization variables
 
@@ -260,7 +260,7 @@ When completing for #+STARTUP, for example, this function returns
 	       (buffer-name (buffer-base-buffer)))))))
 
 
-(declare-function org-export-backend-options "org-export" (cl-x))
+(declare-function org-export-backend-options "ox" (cl-x) t)
 (defun pcomplete/org-mode/file-option/options ()
   "Complete arguments for the #+OPTIONS file option."
   (while (pcomplete-here
